@@ -1,24 +1,11 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import print_function
-from __future__ import absolute_import
-import os
 import sys
 import tempfile
+from pathlib import Path
 
 import numpy as np
 
-import tables
-from tables import (
-    StringCol, BoolCol, FloatCol, ComplexCol, EnumCol,
-    Int8Col, UInt8Col, Int16Col, UInt16Col, Int32Col, UInt32Col,
-    Int64Col, Float32Col, Float64Col, Time64Col
-)
+import tables as tb
 from tables.tests import common
-from tables.tests.common import allequal
-from tables.tests.common import unittest
-from tables.tests.common import PyTablesTestCase as TestCase
-from six.moves import range
 
 
 typecodes = ['b', 'h', 'i', 'l', 'q', 'f', 'd']
@@ -30,17 +17,17 @@ else:
     typecodes += ['B', 'H', 'I', 'L', 'F', 'D']
 typecodes += ['b1']   # boolean
 
-if hasattr(tables, 'Float16Atom'):
+if hasattr(tb, 'Float16Atom'):
     typecodes.append('e')
-if hasattr(tables, 'Float96Atom') or hasattr(tables, 'Float128Atom'):
+if hasattr(tb, 'Float96Atom') or hasattr(tb, 'Float128Atom'):
     typecodes.append('g')
-if hasattr(tables, 'Complex192Atom') or hasattr(tables, 'Conplex256Atom'):
+if hasattr(tb, 'Complex192Atom') or hasattr(tb, 'Conplex256Atom'):
     typecodes.append('G')
 
 byteorder = {'little': '<', 'big': '>'}[sys.byteorder]
 
 
-class BasicTestCase(TestCase):
+class BasicTestCase(common.PyTablesTestCase):
     """Basic test for all the supported typecodes present in NumPy.
 
     All of them are included on PyTables.
@@ -58,7 +45,7 @@ class BasicTestCase(TestCase):
         # Create an instance of HDF5 Table
         self.h5fname = tempfile.mktemp(".h5")
         try:
-            with tables.open_file(self.h5fname, mode="w") as self.h5file:
+            with tb.open_file(self.h5fname, mode="w") as self.h5file:
                 self.root = self.h5file.root
 
                 # Create the array under root and name 'somearray'
@@ -67,7 +54,7 @@ class BasicTestCase(TestCase):
                                          "Some array")
 
             # Re-open the file in read-only mode
-            with tables.open_file(self.h5fname, mode="r") as self.h5file:
+            with tb.open_file(self.h5fname, mode="r") as self.h5file:
                 self.root = self.h5file.root
 
                 # Read the saved array
@@ -102,11 +89,11 @@ class BasicTestCase(TestCase):
                 else:
                     self.assertEqual(a.dtype.base.name, type_)
 
-                self.assertTrue(allequal(a, b, "numpy"))
+                self.assertTrue(common.allequal(a, b, "numpy"))
         finally:
             # Then, delete the file
-            if os.path.exists(self.h5fname):
-                os.remove(self.h5fname)
+            if Path(self.h5fname).is_file():
+                Path(self.h5fname).unlink()
 
     def test00_char(self):
         """Data integrity during recovery (character objects)"""
@@ -150,7 +137,7 @@ class BasicTestCase(TestCase):
 
             # This should not be tested for the rank-0 case
             if len(a.shape) == 0:
-                raise unittest.SkipTest
+                raise common.unittest.SkipTest
             b = a[::2]
 
             # Ensure that this array is non-contiguous (for non-trivial case)
@@ -222,7 +209,7 @@ class Basic10DTestCase(BasicTestCase):
 #     tupleChar = np.array(tupleInt, dtype="S1")
 
 
-class GroupsArrayTestCase(common.TempFileMixin, TestCase):
+class GroupsArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
     """This test class checks combinations of arrays with groups.
 
     It also uses arrays ranks which ranges until 10.
@@ -271,7 +258,7 @@ class GroupsArrayTestCase(common.TempFileMixin, TestCase):
             dset = getattr(group, 'array_' + typecodes[i-1])
             # Get the actual array
             b = dset.read()
-            if not allequal(a, b, "numpy") and common.verbose:
+            if not common.allequal(a, b, "numpy") and common.verbose:
                 print("Array a original. Shape: ==>", a.shape)
                 print("Array a original. Data: ==>", a)
                 print("Info from dataset:", dset._v_pathname)
@@ -286,27 +273,27 @@ class GroupsArrayTestCase(common.TempFileMixin, TestCase):
                     # Special expection. We have no way to distinguish between
                     # "l" and "i" typecode, and we can consider them the same
                     # to all practical effects
-                    self.assertTrue(b.dtype.char == "l" or b.dtype.char == "i")
+                    self.assertIn(b.dtype.char, ("l", "i"))
                 elif (a.dtype.char == "I" or a.dtype.char == "L"):
                     # Special expection. We have no way to distinguish between
                     # "L" and "I" typecode, and we can consider them the same
                     # to all practical effects
-                    self.assertTrue(b.dtype.char == "L" or b.dtype.char == "I")
+                    self.assertIn(b.dtype.char, ("L", "I"))
                 else:
-                    self.assertTrue(allequal(a, b, "numpy"))
+                    self.assertTrue(common.allequal(a, b, "numpy"))
             elif np.dtype('l').itemsize == 8:
                 if (a.dtype.char == "q" or a.dtype.char == "l"):
                     # Special expection. We have no way to distinguish between
                     # "q" and "l" typecode in 64-bit platforms, and we can
                     # consider them the same to all practical effects
-                    self.assertTrue(b.dtype.char == "l" or b.dtype.char == "q")
+                    self.assertIn(b.dtype.char, ("l", "q"))
                 elif (a.dtype.char == "Q" or a.dtype.char == "L"):
                     # Special expection. We have no way to distinguish between
                     # "Q" and "L" typecode in 64-bit platforms, and we can
                     # consider them the same to all practical effects
-                    self.assertTrue(b.dtype.char == "L" or b.dtype.char == "Q")
+                    self.assertIn(b.dtype.char, ("L", "Q"))
                 else:
-                    self.assertTrue(allequal(a, b, "numpy"))
+                    self.assertTrue(common.allequal(a, b, "numpy"))
 
             # Iterate over the next group
             group = getattr(group, 'group' + str(i))
@@ -370,7 +357,7 @@ class GroupsArrayTestCase(common.TempFileMixin, TestCase):
                 # Special expection. We have no way to distinguish between
                 # "l" and "i" typecode, and we can consider them the same
                 # to all practical effects
-                self.assertTrue(b.dtype.char == "l" or b.dtype.char == "i")
+                self.assertIn(b.dtype.char, ("l", "i"))
             else:
                 self.assertEqual(a.dtype.char, b.dtype.char)
 
@@ -384,38 +371,38 @@ class GroupsArrayTestCase(common.TempFileMixin, TestCase):
 
 
 # Test Record class
-class Record(tables.IsDescription):
-    var1 = StringCol(itemsize=4, dflt=b"abcd", pos=0)
-    var2 = StringCol(itemsize=1, dflt=b"a", pos=1)
-    var3 = BoolCol(dflt=1)
-    var4 = Int8Col(dflt=1)
-    var5 = UInt8Col(dflt=1)
-    var6 = Int16Col(dflt=1)
-    var7 = UInt16Col(dflt=1)
-    var8 = Int32Col(dflt=1)
-    var9 = UInt32Col(dflt=1)
-    var10 = Int64Col(dflt=1)
-    var11 = Float32Col(dflt=1.0)
-    var12 = Float64Col(dflt=1.0)
-    var13 = ComplexCol(itemsize=8, dflt=(1.+0.j))
-    var14 = ComplexCol(itemsize=16, dflt=(1.+0.j))
-    if hasattr(tables, 'Float16Col'):
-        var15 = tables.Float16Col(dflt=1.0)
-    if hasattr(tables, 'Float96Col'):
-        var16 = tables.Float96Col(dflt=1.0)
-    if hasattr(tables, 'Float128Col'):
-        var17 = tables.Float128Col(dflt=1.0)
-    if hasattr(tables, 'Complex196Col'):
-        var18 = tables.ComplexCol(itemsize=24, dflt=(1.+0.j))
-    if hasattr(tables, 'Complex256Col'):
-        var19 = tables.ComplexCol(itemsize=32, dflt=(1.+0.j))
+class Record(tb.IsDescription):
+    var1 = tb.StringCol(itemsize=4, dflt=b"abcd", pos=0)
+    var2 = tb.StringCol(itemsize=1, dflt=b"a", pos=1)
+    var3 = tb.BoolCol(dflt=1)
+    var4 = tb.Int8Col(dflt=1)
+    var5 = tb.UInt8Col(dflt=1)
+    var6 = tb.Int16Col(dflt=1)
+    var7 = tb.UInt16Col(dflt=1)
+    var8 = tb.Int32Col(dflt=1)
+    var9 = tb.UInt32Col(dflt=1)
+    var10 = tb.Int64Col(dflt=1)
+    var11 = tb.Float32Col(dflt=1.0)
+    var12 = tb.Float64Col(dflt=1.0)
+    var13 = tb.ComplexCol(itemsize=8, dflt=(1.+0.j))
+    var14 = tb.ComplexCol(itemsize=16, dflt=(1.+0.j))
+    if hasattr(tb, 'Float16Col'):
+        var15 = tb.Float16Col(dflt=1.0)
+    if hasattr(tb, 'Float96Col'):
+        var16 = tb.Float96Col(dflt=1.0)
+    if hasattr(tb, 'Float128Col'):
+        var17 = tb.Float128Col(dflt=1.0)
+    if hasattr(tb, 'Complex196Col'):
+        var18 = tb.ComplexCol(itemsize=24, dflt=(1.+0.j))
+    if hasattr(tb, 'Complex256Col'):
+        var19 = tb.ComplexCol(itemsize=32, dflt=(1.+0.j))
 
 
-class TableReadTestCase(common.TempFileMixin, TestCase):
+class TableReadTestCase(common.TempFileMixin, common.PyTablesTestCase):
     nrows = 100
 
     def setUp(self):
-        super(TableReadTestCase, self).setUp()
+        super().setUp()
 
         # Create an instance of an HDF5 Table
         table = self.h5file.create_table(self.h5file.root, 'table', Record)
@@ -451,7 +438,7 @@ class TableReadTestCase(common.TempFileMixin, TestCase):
                     print("Should look like:", orignumcol.shape)
                     print("First 3 elements of read col:", numcol[:3])
                 # Check that both NumPy objects are equal
-                self.assertTrue(allequal(numcol, orignumcol, "numpy"))
+                self.assertTrue(common.allequal(numcol, orignumcol, "numpy"))
 
     def test01_readTableNum(self):
         """Checking column conversion into NumPy in read().
@@ -465,7 +452,6 @@ class TableReadTestCase(common.TempFileMixin, TestCase):
         for colname in table.colnames:
             numcol = table.read(field=colname)
             typecol = table.coltypes[colname]
-            #nctypecode = np.typeNA[numcol.dtype.char[0]]
             nctypecode = np.sctypeDict[numcol.dtype.char[0]]
             if typecol != "string":
                 if common.verbose:
@@ -473,7 +459,7 @@ class TableReadTestCase(common.TempFileMixin, TestCase):
                     print("Should look like:", typecol)
                 orignumcol = np.ones(shape=self.nrows, dtype=numcol.dtype.char)
                 # Check that both NumPy objects are equal
-                self.assertTrue(allequal(numcol, orignumcol, "numpy"))
+                self.assertTrue(common.allequal(numcol, orignumcol, "numpy"))
 
     def test02_readCoordsChar(self):
         """Column conversion into NumPy in readCoords().
@@ -504,7 +490,7 @@ class TableReadTestCase(common.TempFileMixin, TestCase):
                     print("Should look like:", orignumcol.shape)
                     print("First 3 elements of read col:", numcol[:3])
                 # Check that both NumPy objects are equal
-                self.assertTrue(allequal(numcol, orignumcol, "numpy"))
+                self.assertTrue(common.allequal(numcol, orignumcol, "numpy"))
 
     def test02_readCoordsNum(self):
         """Column conversion into NumPy in read_coordinates().
@@ -529,7 +515,7 @@ class TableReadTestCase(common.TempFileMixin, TestCase):
                     print("Should look like:", typecol)
                 orignumcol = np.ones(shape=self.nrows, dtype=numcol.dtype.char)
                 # Check that both NumPy objects are equal
-                self.assertTrue(allequal(numcol, orignumcol, "numpy"))
+                self.assertTrue(common.allequal(numcol, orignumcol, "numpy"))
 
     def test03_getIndexNumPy(self):
         """Getting table rows specifyied as NumPy scalar integers."""
@@ -550,7 +536,7 @@ class TableReadTestCase(common.TempFileMixin, TestCase):
                 orignumcol = np.ones(shape=len(numcol),
                                      dtype=numcol.dtype.char)
                 # Check that both NumPy objects are equal
-                self.assertTrue(allequal(numcol, orignumcol, "numpy"))
+                self.assertTrue(common.allequal(numcol, orignumcol, "numpy"))
 
     def test04_setIndexNumPy(self):
         """Setting table rows specifyied as NumPy integers."""
@@ -583,41 +569,41 @@ class TableReadTestCase(common.TempFileMixin, TestCase):
 
 
 # The declaration of the nested table:
-class Info(tables.IsDescription):
+class Info(tb.IsDescription):
     _v_pos = 3
-    Name = StringCol(itemsize=2)
-    Value = ComplexCol(itemsize=16)
+    Name = tb.StringCol(itemsize=2)
+    Value = tb.ComplexCol(itemsize=16)
 
 
-class TestTDescr(tables.IsDescription):
+class TestTDescr(tb.IsDescription):
 
     """A description that has several nested columns."""
 
-    x = Int32Col(dflt=0, shape=2, pos=0)  # 0
-    y = FloatCol(dflt=1, shape=(2, 2))
-    z = UInt8Col(dflt=1)
-    z3 = EnumCol({'r': 4, 'g': 2, 'b': 1}, 'r', 'int32', shape=2)
-    color = StringCol(itemsize=4, dflt=b"ab", pos=2)
+    x = tb.Int32Col(dflt=0, shape=2, pos=0)  # 0
+    y = tb.FloatCol(dflt=1, shape=(2, 2))
+    z = tb.UInt8Col(dflt=1)
+    z3 = tb.EnumCol({'r': 4, 'g': 2, 'b': 1}, 'r', 'int32', shape=2)
+    color = tb.StringCol(itemsize=4, dflt=b"ab", pos=2)
     info = Info()
 
-    class Info(tables.IsDescription):  # 1
+    class Info(tb.IsDescription):  # 1
         _v_pos = 1
-        name = StringCol(itemsize=2)
-        value = ComplexCol(itemsize=16, pos=0)  # 0
-        y2 = FloatCol(pos=1)  # 1
-        z2 = UInt8Col()
+        name = tb.StringCol(itemsize=2)
+        value = tb.ComplexCol(itemsize=16, pos=0)  # 0
+        y2 = tb.FloatCol(pos=1)  # 1
+        z2 = tb.UInt8Col()
 
-        class Info2(tables.IsDescription):
-            y3 = Time64Col(shape=2)
-            name = StringCol(itemsize=2)
-            value = ComplexCol(itemsize=16, shape=2)
+        class Info2(tb.IsDescription):
+            y3 = tb.Time64Col(shape=2)
+            name = tb.StringCol(itemsize=2)
+            value = tb.ComplexCol(itemsize=16, shape=2)
 
 
-class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
+class TableNativeFlavorTestCase(common.TempFileMixin, common.PyTablesTestCase):
     nrows = 100
 
     def setUp(self):
-        super(TableNativeFlavorTestCase, self).setUp()
+        super().setUp()
 
         # Create an instance of an HDF5 Table
         table = self.h5file.create_table(self.h5file.root, 'table', TestTDescr,
@@ -640,18 +626,18 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("First 3 elements of read:", data[:3])
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the value of some columns
         # A flat column
         col = table.cols.x[:3]
-        self.assertTrue(isinstance(col, np.ndarray))
+        self.assertIsInstance(col, np.ndarray)
         npcol = np.zeros((3, 2), dtype="int32")
-        self.assertTrue(allequal(col, npcol, "numpy"))
+        self.assertTrue(common.allequal(col, npcol, "numpy"))
 
         # A nested column
         col = table.cols.Info[:3]
-        self.assertTrue(isinstance(col, np.ndarray))
+        self.assertIsInstance(col, np.ndarray)
         dtype = [('value', 'c16'),
                  ('y2', 'f8'),
                  ('Info2',
@@ -682,18 +668,18 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("First 3 elements of read:", data[:3])
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the value of some columns
         # A flat column
         col = table.cols.x[:9:3]
-        self.assertTrue(isinstance(col, np.ndarray))
+        self.assertIsInstance(col, np.ndarray)
         npcol = np.zeros((3, 2), dtype="int32")
-        self.assertTrue(allequal(col, npcol, "numpy"))
+        self.assertTrue(common.allequal(col, npcol, "numpy"))
 
         # A nested column
         col = table.cols.Info[:9:3]
-        self.assertTrue(isinstance(col, np.ndarray))
+        self.assertIsInstance(col, np.ndarray)
         dtype = [('value', '%sc16' % byteorder),
                  ('y2', '%sf8' % byteorder),
                  ('Info2',
@@ -724,13 +710,14 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("First 3 elements of read:", data[:3])
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check that all columns have been selected
         self.assertEqual(len(data), 100)
 
         # Finally, check that the contents are ok
-        self.assertTrue(allequal(data, np.arange(100, dtype="i8"), "numpy"))
+        self.assertTrue(common.allequal(
+            data, np.arange(100, dtype="i8"), "numpy"))
 
     def test03a_readWhere(self):
         """Checking the return of NumPy in read_where method (strings)."""
@@ -746,7 +733,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check that all columns have been selected
         self.assertEqual(len(data), self.nrows)
@@ -765,7 +752,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check that all columns have been selected
         self.assertEqual(len(data), 0)
@@ -794,7 +781,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, npdata.dtype.descr)
@@ -822,7 +809,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, npdata.dtype.descr)
@@ -849,13 +836,14 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check that all columns have been selected
         self.assertEqual(len(data), 100)
 
         # Finally, check that the contents are ok
-        self.assertTrue(allequal(data, np.zeros((100,), dtype="u1"), "numpy"))
+        self.assertTrue(common.allequal(
+            data, np.zeros((100,), dtype="u1"), "numpy"))
 
     def test05b_modifyingColumns(self):
         """Checking modifying several columns at once."""
@@ -876,7 +864,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, ycol.dtype.descr)
@@ -906,7 +894,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, ycol.dtype.descr)
@@ -943,7 +931,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, npdata.dtype.descr)
@@ -967,8 +955,8 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
                  ('name', '|S2'),
                  ('z2', '|u1')]
         npdata = np.zeros((3,), dtype=dtype)
-        #self.assertRaises(NotImplementedError,
-        #                  table.cols.Info.__setitem__, slice(3,6,1),  npdata)
+        # self.assertRaises(NotImplementedError,
+        #                   table.cols.Info.__setitem__, slice(3,6,1),  npdata)
         table.cols.Info[3:6] = npdata
         if self.close:
             self._reopen(mode='a')
@@ -981,7 +969,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, npdata.dtype.descr)
@@ -1015,14 +1003,14 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, ycol.dtype.descr)
         if common.verbose:
             print("ycol-->", ycol)
             print("data-->", data)
-        self.assertTrue(allequal(ycol, data, "numpy"))
+        self.assertTrue(common.allequal(ycol, data, "numpy"))
 
     def test07b_modifyingRows(self):
         """Checking modifying several rows at once (using cols accessor)."""
@@ -1049,14 +1037,14 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, ycol.dtype.descr)
         if common.verbose:
             print("ycol-->", ycol)
             print("data-->", data)
-        self.assertTrue(allequal(ycol, data, "numpy"))
+        self.assertTrue(common.allequal(ycol, data, "numpy"))
 
     def test08a_modifyingRows(self):
         """Checking modifying just one row at once (using modify_rows)."""
@@ -1083,14 +1071,14 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, ycol.dtype.descr)
         if common.verbose:
             print("ycol-->", ycol)
             print("data-->", data)
-        self.assertTrue(allequal(ycol, data, "numpy"))
+        self.assertTrue(common.allequal(ycol, data, "numpy"))
 
     def test08b_modifyingRows(self):
         """Checking modifying just one row at once (using cols accessor)."""
@@ -1117,14 +1105,14 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("Length of the data read:", len(data))
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, ycol.dtype.descr)
         if common.verbose:
             print("ycol-->", ycol)
             print("data-->", data)
-        self.assertTrue(allequal(ycol, data, "numpy"))
+        self.assertTrue(common.allequal(ycol, data, "numpy"))
 
     def test09a_getStrings(self):
         """Checking the return of string columns with spaces."""
@@ -1140,7 +1128,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("First 3 elements of read:", data[:3])
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check that all columns have been selected
         self.assertEqual(len(data), 100)
@@ -1169,7 +1157,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("First 3 elements of read:", data[:3])
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check that all columns have been selected
         self.assertEqual(len(data), 100)
@@ -1199,7 +1187,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
         table.flush()
         if self.close:
             self.h5file.close()
-            self.h5file = tables.open_file(self.h5fname, "a")
+            self.h5file = tb.open_file(self.h5fname, "a")
         data = self.h5file.root.table[:]
         if common.verbose:
             print("Type of read:", type(data))
@@ -1207,7 +1195,7 @@ class TableNativeFlavorTestCase(common.TempFileMixin, TestCase):
             print("First 3 elements of read:", data[:3])
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check that all columns have been selected
         self.assertEqual(len(data), 150)
@@ -1229,9 +1217,9 @@ class TableNativeFlavorCloseTestCase(TableNativeFlavorTestCase):
     close = True
 
 
-class AttributesTestCase(common.TempFileMixin, TestCase):
+class AttributesTestCase(common.TempFileMixin, common.PyTablesTestCase):
     def setUp(self):
-        super(AttributesTestCase, self).setUp()
+        super().setUp()
 
         # Create an instance of an HDF5 Table
         self.h5file.create_group(self.h5file.root, 'group')
@@ -1252,14 +1240,14 @@ class AttributesTestCase(common.TempFileMixin, TestCase):
         npcomp = np.zeros((1, 1), dtype='int16')
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, npcomp.dtype.descr)
         if common.verbose:
             print("npcomp-->", npcomp)
             print("data-->", data)
-        self.assertTrue(allequal(npcomp, data, "numpy"))
+        self.assertTrue(common.allequal(npcomp, data, "numpy"))
 
     def test02_updateAttribute(self):
         """Checking the modification of a numpy attribute."""
@@ -1280,14 +1268,14 @@ class AttributesTestCase(common.TempFileMixin, TestCase):
         npcomp = np.ones((1, 2), dtype='int16')
 
         # Check that both NumPy objects are equal
-        self.assertTrue(isinstance(data, np.ndarray))
+        self.assertIsInstance(data, np.ndarray)
 
         # Check the type
         self.assertEqual(data.dtype.descr, npcomp.dtype.descr)
         if common.verbose:
             print("npcomp-->", npcomp)
             print("data-->", data)
-        self.assertTrue(allequal(npcomp, data, "numpy"))
+        self.assertTrue(common.allequal(npcomp, data, "numpy"))
 
 
 class AttributesOpenTestCase(AttributesTestCase):
@@ -1298,13 +1286,13 @@ class AttributesCloseTestCase(AttributesTestCase):
     close = 1
 
 
-class StrlenTestCase(common.TempFileMixin, TestCase):
+class StrlenTestCase(common.TempFileMixin, common.PyTablesTestCase):
     def setUp(self):
-        super(StrlenTestCase, self).setUp()
+        super().setUp()
 
         # Create an instance of an HDF5 Table
         group = self.h5file.create_group(self.h5file.root, 'group')
-        tablelayout = {'Text': StringCol(itemsize=1000), }
+        tablelayout = {'Text': tb.StringCol(itemsize=1000), }
         self.table = self.h5file.create_table(group, 'table', tablelayout)
         self.table.flavor = 'numpy'
         row = self.table.row
@@ -1378,29 +1366,31 @@ class StrlenCloseTestCase(StrlenTestCase):
 
 
 def suite():
-    theSuite = unittest.TestSuite()
+    theSuite = common.unittest.TestSuite()
     niter = 1
 
     # theSuite.addTest(unittest.makeSuite(StrlenOpenTestCase))
     # theSuite.addTest(unittest.makeSuite(Basic0DOneTestCase))
     # theSuite.addTest(unittest.makeSuite(GroupsArrayTestCase))
     for i in range(niter):
-        theSuite.addTest(unittest.makeSuite(Basic0DOneTestCase))
-        theSuite.addTest(unittest.makeSuite(Basic0DTwoTestCase))
-        theSuite.addTest(unittest.makeSuite(Basic1DOneTestCase))
-        theSuite.addTest(unittest.makeSuite(Basic1DTwoTestCase))
-        theSuite.addTest(unittest.makeSuite(Basic1DThreeTestCase))
-        theSuite.addTest(unittest.makeSuite(Basic2DTestCase))
-        theSuite.addTest(unittest.makeSuite(GroupsArrayTestCase))
-        theSuite.addTest(unittest.makeSuite(TableReadTestCase))
-        theSuite.addTest(unittest.makeSuite(TableNativeFlavorOpenTestCase))
-        theSuite.addTest(unittest.makeSuite(TableNativeFlavorCloseTestCase))
-        theSuite.addTest(unittest.makeSuite(AttributesOpenTestCase))
-        theSuite.addTest(unittest.makeSuite(AttributesCloseTestCase))
-        theSuite.addTest(unittest.makeSuite(StrlenOpenTestCase))
-        theSuite.addTest(unittest.makeSuite(StrlenCloseTestCase))
+        theSuite.addTest(common.unittest.makeSuite(Basic0DOneTestCase))
+        theSuite.addTest(common.unittest.makeSuite(Basic0DTwoTestCase))
+        theSuite.addTest(common.unittest.makeSuite(Basic1DOneTestCase))
+        theSuite.addTest(common.unittest.makeSuite(Basic1DTwoTestCase))
+        theSuite.addTest(common.unittest.makeSuite(Basic1DThreeTestCase))
+        theSuite.addTest(common.unittest.makeSuite(Basic2DTestCase))
+        theSuite.addTest(common.unittest.makeSuite(GroupsArrayTestCase))
+        theSuite.addTest(common.unittest.makeSuite(TableReadTestCase))
+        theSuite.addTest(
+            common.unittest.makeSuite(TableNativeFlavorOpenTestCase))
+        theSuite.addTest(
+            common.unittest.makeSuite(TableNativeFlavorCloseTestCase))
+        theSuite.addTest(common.unittest.makeSuite(AttributesOpenTestCase))
+        theSuite.addTest(common.unittest.makeSuite(AttributesCloseTestCase))
+        theSuite.addTest(common.unittest.makeSuite(StrlenOpenTestCase))
+        theSuite.addTest(common.unittest.makeSuite(StrlenCloseTestCase))
         if common.heavy:
-            theSuite.addTest(unittest.makeSuite(Basic10DTestCase))
+            theSuite.addTest(common.unittest.makeSuite(Basic10DTestCase))
             # The 32 dimensions case takes forever to run!!
             # theSuite.addTest(unittest.makeSuite(Basic32DTestCase))
     return theSuite
@@ -1409,4 +1399,4 @@ def suite():
 if __name__ == '__main__':
     common.parse_argv(sys.argv)
     common.print_versions()
-    unittest.main(defaultTest='suite')
+    common.unittest.main(defaultTest='suite')
